==> hplip-0.9.3-i486-1kjz.tgz: install/doinst.sh <==
( cd usr/bin ; rm -rf hp-align )
( cd usr/bin ; ln -sf ../share/hplip/align hp-align )
( cd usr/bin ; rm -rf hp-info )
( cd usr/bin ; ln -sf ../share/hplip/info hp-info )
( cd usr/bin ; rm -rf hp-print )
( cd usr/bin ; ln -sf ../share/hplip/print hp-print )
( cd usr/bin ; rm -rf hp-toolbox )
( cd usr/bin ; ln -sf ../share/hplip/toolbox hp-toolbox )
( cd usr/bin ; rm -rf hp-clean )
( cd usr/bin ; ln -sf ../share/hplip/clean hp-clean )
( cd usr/bin ; rm -rf hp-colorcal )
( cd usr/bin ; ln -sf ../share/hplip/colorcal hp-colorcal )
( cd usr/bin ; rm -rf hp-photo )
( cd usr/bin ; ln -sf ../share/hplip/photo hp-photo )
( cd usr/bin ; rm -rf hp-unload )
( cd usr/bin ; ln -sf ../share/hplip/unload hp-unload )
( cd usr/bin ; rm -rf hp-probe )
( cd usr/bin ; ln -sf ../share/hplip/probe hp-probe )
( cd usr/bin ; rm -rf hp-rpu )
( cd usr/bin ; ln -sf ../share/hplip/rpu hp-rpu )
( cd usr/bin ; rm -rf hp-testpage )
( cd usr/bin ; ln -sf ../share/hplip/testpage hp-testpage )
( cd usr/bin ; rm -rf hp-makeuri )
( cd usr/bin ; ln -sf ../share/hplip/makeuri hp-makeuri )
( cd usr/bin ; rm -rf hp-check )
( cd usr/bin ; ln -sf ../share/hplip/check hp-check )
( cd usr/share/cups/model ; rm -rf foomatic-ppds )
( cd usr/share/cups/model ; ln -sf /usr/share/ppd foomatic-ppds )
( cd usr/share/applications ; rm -rf hplip.desktop )
( cd usr/share/applications ; ln -sf /usr/share/hplip/data/hplip.desktop hplip.desktop )
( cd usr/lib/cups/filter ; rm -rf foomatic-rip )
( cd usr/lib/cups/filter ; ln -sf /usr/bin/foomatic-rip foomatic-rip )
( cd usr/lib ; rm -rf libhpip.so.0 )
( cd usr/lib ; ln -sf libhpip.so.0.0.1 libhpip.so.0 )
( cd usr/lib ; rm -rf libhpip.so )
( cd usr/lib ; ln -sf libhpip.so.0.0.1 libhpip.so )
( cd usr/lib ; rm -rf libsane-hpaio.so.1 )
( cd usr/lib ; ln -sf libsane-hpaio.so.1.0.0 libsane-hpaio.so.1 )
( cd usr/lib ; rm -rf libsane-hpaio.so )
( cd usr/lib ; ln -sf libsane-hpaio.so.1.0.0 libsane-hpaio.so )
( cd usr/lib/sane ; rm -rf libsane-hpaio.so )
( cd usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so )
( cd usr/lib/sane ; rm -rf libsane-hpaio.so.1 )
( cd usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so.1 )
( cd usr/lib/sane ; rm -rf libsane-hpaio.so.1.0.0 )
( cd usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so.1.0.0 )

==> hplip-0.9.4-i486-1kjz.tgz: install/doinst.sh <==
( cd usr/bin ; rm -rf hp-align )
( cd usr/bin ; ln -sf ../share/hplip/align hp-align )
( cd usr/bin ; rm -rf hp-info )
( cd usr/bin ; ln -sf ../share/hplip/info hp-info )
( cd usr/bin ; rm -rf hp-print )
( cd usr/bin ; ln -sf ../share/hplip/print hp-print )
( cd usr/bin ; rm -rf hp-toolbox )
( cd usr/bin ; ln -sf ../share/hplip/toolbox hp-toolbox )
( cd usr/bin ; rm -rf hp-clean )
( cd usr/bin ; ln -sf ../share/hplip/clean hp-clean )
( cd usr/bin ; rm -rf hp-colorcal )
( cd usr/bin ; ln -sf ../share/hplip/colorcal hp-colorcal )
( cd usr/bin ; rm -rf hp-photo )
( cd usr/bin ; ln -sf ../share/hplip/photo hp-photo )
( cd usr/bin ; rm -rf hp-unload )
( cd usr/bin ; ln -sf ../share/hplip/unload hp-unload )
( cd usr/bin ; rm -rf hp-probe )
( cd usr/bin ; ln -sf ../share/hplip/probe hp-probe )
( cd usr/bin ; rm -rf hp-testpage )
( cd usr/bin ; ln -sf ../share/hplip/testpage hp-testpage )
( cd usr/bin ; rm -rf hp-makeuri )
( cd usr/bin ; ln -sf ../share/hplip/makeuri hp-makeuri )
( cd usr/bin ; rm -rf hp-check )
( cd usr/bin ; ln -sf ../share/hplip/check hp-check )
( cd usr/bin ; rm -rf hp-fab )
( cd usr/bin ; ln -sf ../share/hplip/fab hp-fab )
( cd usr/share/cups/model ; rm -rf foomatic-ppds )
( cd usr/share/cups/model ; ln -sf /usr/share/ppd foomatic-ppds )
( cd usr/share/applications ; rm -rf hplip.desktop )
( cd usr/share/applications ; ln -sf /usr/share/hplip/data/hplip.desktop hplip.desktop )
( cd usr/lib/cups/filter ; rm -rf foomatic-rip )
( cd usr/lib/cups/filter ; ln -sf /usr/bin/foomatic-rip foomatic-rip )
( cd usr/lib ; rm -rf libhpip.so.0 )
( cd usr/lib ; ln -sf libhpip.so.0.0.1 libhpip.so.0 )
( cd usr/lib ; rm -rf libhpip.so )
( cd usr/lib ; ln -sf libhpip.so.0.0.1 libhpip.so )
( cd usr/lib ; rm -rf libsane-hpaio.so.1 )
( cd usr/lib ; ln -sf libsane-hpaio.so.1.0.0 libsane-hpaio.so.1 )
( cd usr/lib ; rm -rf libsane-hpaio.so )
( cd usr/lib ; ln -sf libsane-hpaio.so.1.0.0 libsane-hpaio.so )
( cd usr/lib/sane ; rm -rf libsane-hpaio.so )
( cd usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so )
( cd usr/lib/sane ; rm -rf libsane-hpaio.so.1 )
( cd usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so.1 )
( cd usr/lib/sane ; rm -rf libsane-hpaio.so.1.0.0 )
( cd usr/lib/sane ; ln -sf ../libsane-hpaio.so.1.0.0 libsane-hpaio.so.1.0.0 )
